/*
TEST APPLICATION
*/

#include "main.h"
//Added include directory and library path
#include "ti\dsplib\dsplib.h"


//Error
unsigned char errorNum = 	ERROR_NOERROR;
//Control Array
extern union 			inFuncData_union inFuncDataArray;
extern union 			outFuncData_union outFuncDataArray;


//-----------------------------------------------------------------------------------------------------------------------------
// User Define Variable - Use External Memory for All Large Variables
// Internal Memory Reserved for DMA and UART Operations

int Stim[2][AUDIO_SAMPLES_MAX];
int MicRv[2][AUDIO_SAMPLES_MAX];





#define NUM_FILTERS 5
struct FilterStorage_t LEFilterStorage[NUM_FILTERS];
struct FilterStorage_t REFilterStorage[NUM_FILTERS];

int main(void)
{
    //-----------------------------------------------------------------------------------------------------------------------------
    //Setup the DSP
    //-----------------------------------------------------------------------------------------------------------------------------
    int sampling_rate;
    int buffer_length;

    IHS_initializeDSP();
    //Setup the audio codec and its interfaces
    sampling_rate=24000;
    //sampling_rate=48000;
    buffer_length=AUDIO_SAMPLES_MAX; //Should be less than or equal to AUDIO_SAMPLES_MAX
    buffer_length=600; //Should be less than or equal to AUDIO_SAMPLES_MAX
    codecSettings_t codecSettings;
//    codecSettings.dmaFlag =             CODECONFIG_NO_DMA;
    codecSettings.dmaFlag =             CODECONFIG_USE_DMA;
    codecSettings.samplingRate =        sampling_rate;
    codecSettings.wordSize =            WORD_SIZE;
    codecSettings.enableHPL =           1;      /* Enable headphone output for left  ch */
    codecSettings.enableHPR =           1;      /* Enable headphone output for right ch */
    codecSettings.enableIN1L =          1;      /* Enable mic input for left  ch */
    codecSettings.enableIN1R =          1;      /* Enable mic input for right ch */
    codecSettings.enableLOR =           0;      /* Enable aux line output for left ch */
    codecSettings.enableIN2R =          0;      /* Enable aux line input for right ch */
    codecSettings.gainMicLeft =         0;      /* 0 to 47.5 dB*/
    codecSettings.gainMicRight =        0;      /* 0 to 47.5 dB*/
    codecSettings.gainHeadphoneLeft =   -6;      /*-6 to 29 dB*/
    codecSettings.gainHeadphoneRight =  -6;      /*-6 to 29 dB*/
    codecSettings.gainLineoutRight =    0;      /*-6 to 29 dB*/
    //-----------------------------------------------------------------------------------------------------------------------------
    //PC Function Call Variables...
    unsigned short FuncNum;
    unsigned int   FuncDataLength;
    //-----------------------------------------------------------------------------------------------------------------------------


    //Misc variables
    int i;
    int f;
    int n=1;

    LED(0,1);
    delay_ms(100);


    for(i=0 ; i<AUDIO_SAMPLES_MAX; i++)
    {
        Stim[0][i]  = 0;
        Stim[1][i]  = 0;
    }


    //-----------------------------------------------------------------------------------------------------------------------------
    //Initialize Output
    audio_writeTxBuffers(&Stim[0][0], &Stim[1][0], buffer_length);
    int32_t result = IHS_initializeCodec(&codecSettings, buffer_length);
    I2SDataTxRxActivate(&codecSettings);
    //-----------------------------------------------------------------------------------------------------------------------------

    LED(0,0);

    //Parameters: Fs = 24kSps, Poles = 2
    //FCenter = 750Hz, FcLower = 650Hz, FcUpper = 867Hz
    float bTemp1[5] = {0.000784, 0.000000, -0.001569, 0.000000, 0.000784};
    float aTemp1[5] = {1.000000, -3.843913, 5.614603, -3.691644, 0.922374};
    FilterFunc_init(LEFilterStorage, 0, 2, 5, bTemp1, 5, aTemp1);
    FilterFunc_init(REFilterStorage, 0, 2, 5, bTemp1, 5, aTemp1);

    //FCenter = 1500Hz, FcLower = 1300Hz, FcUpper = 1733Hz
    float bTemp2[5] = {0.002978, 0.000000, -0.005956, 0.000000, 0.002978};
    float aTemp2[5] = {1.000000, -3.547139, 4.990047, -3.273181, 0.851719};
    FilterFunc_init(LEFilterStorage, 1, 2, 5, bTemp2, 5, aTemp2);
    FilterFunc_init(REFilterStorage, 1, 2, 5, bTemp2, 5, aTemp2);

    //FCenter = 3000Hz, FcLower = 2595Hz, FcUpper = 3465Hz
    float bTemp3[5] = {0.011135, 0.000000, -0.022271, 0.000000, 0.011135};
    float aTemp3[5] = {1.000000, -2.598534, 3.377639, -2.209660, 0.724635};
    FilterFunc_init(LEFilterStorage, 2, 2, 5, bTemp3, 5, aTemp3);
    FilterFunc_init(REFilterStorage, 2, 2, 5, bTemp3, 5, aTemp3);

    //FCenter = 6000Hz, FcLower = 5190Hz, FcUpper = 6938Hz
    float bTemp4[5] = {0.039181, 0.000000, -0.078363, 0.000000, 0.039181};
    float aTemp4[5] = {1.000000, 0.057699, 1.368130, 0.041387, 0.524007};
    FilterFunc_init(LEFilterStorage, 3, 2, 5, bTemp4, 5, aTemp4);
    FilterFunc_init(REFilterStorage, 3, 2, 5, bTemp4, 5, aTemp4);

    //FCenter = 9000Hz, FcLower = 7800Hz, FcUpper = 10403Hz
    float bTemp5[5] = {0.077236, 0.000000, -0.154471, 0.000000, 0.077236};
    float aTemp5[5] = {1.000000, 2.367105, 2.531865, 1.418264, 0.383742};
    FilterFunc_init(LEFilterStorage, 4, 2, 5, bTemp5, 5, aTemp5);
    FilterFunc_init(REFilterStorage, 4, 2, 5, bTemp5, 5, aTemp5);
    while(1)
    {

        if(PCFunction(&FuncNum,&FuncDataLength))
        {
              switch(FuncNum)
              {

                   case 201://Send Right Mic to PC
                        for(i=0 ; i<buffer_length ; i++)
                       {
                            outFuncDataArray.asInt[i] = (int) Stim[0][i];
                       }
                        sendDataVIARingBuffer(201, outFuncDataArray.asUChar, buffer_length*4);
                        //sendDataVIARingBufferNoDMA(201, outFuncDataArray.asUChar,AUDIO_SAMPLES_MAX*4); //Non-DMA option
                       break;
                   case 202://Send Left Mic to PC
                       for(i=0 ; i<buffer_length ; i++)
                       {
                          outFuncDataArray.asInt[i] = (int) Stim[1][i];
                       }
                       sendDataVIARingBuffer(201, outFuncDataArray.asUChar, buffer_length*4);
                       //sendDataVIARingBufferNoDMA(202, outFuncDataArray.asUChar, AUDIO_SAMPLES_MAX*4); //Non-DMA option
                       break;
                  default: //Undefined Funciton Call from PC - Return Error Message back to PC
                      PCFunctionSendError(ERROR_PROCO_UNDEFINED_FUNCTION_RX);
                      break;
              }
          }





        //-----------------------------------------------------------------------------------------------------------------------------
        //Check if Audio Buffers are Ready... and start processing...
        //-----------------------------------------------------------------------------------------------------------------------------
        if(audio_checkForRx())
        {
            //-----------------------------------------------------------------------------------------------------------------------------
            //Scrolling LED Display
            //-----------------------------------------------------------------------------------------------------------------------------
            LED(n,0);
            n++;
            if (n>4) { n=1; }
            LED(n,1);


            //-----------------------------------------------------------------------------------------------------------------------------
            //Setup Buffer Pointers - REQUIRED
            //-----------------------------------------------------------------------------------------------------------------------------
            audio_updateBuffIndex();

            //-----------------------------------------------------------------------------------------------------------------------------
            //Read Last Buffer
            //-----------------------------------------------------------------------------------------------------------------------------
            audio_receive(&MicRv[0][0], &MicRv[1][0], buffer_length);
            //audio_receive(&Stim[0][0], &Stim[1][0], buffer_length);  //Enable to Echo


            for (i=0; i<buffer_length; i++)
            {
                    for(f=0 ; f<NUM_FILTERS ; f++)
                    //for(f=0 ; f<3 ; f++)
                    {
                        FilterFunc_filter(LEFilterStorage, f, (float)MicRv[0][i]);
                        FilterFunc_filter(REFilterStorage, f, (float)MicRv[1][i]);
                    }


                    //Weight Values can be added to each filter band to adjust the output level accordingly...
                    Stim[0][i] = (int)
                        (
                                    ( (LEFilterStorage[0].pyArray[0]) + LEFilterStorage[1].pyArray[0] + LEFilterStorage[2].pyArray[0]
                                            + LEFilterStorage[3].pyArray[0] + LEFilterStorage[4].pyArray[0])
//                                  (LEFilterStorage[1].pyArray[0])  //Only one band

                        );
                    Stim[1][i] = (int)
                        (
                                    (REFilterStorage[0].pyArray[0] + REFilterStorage[1].pyArray[0] + REFilterStorage[2].pyArray[0]
                                            + REFilterStorage[3].pyArray[0] + REFilterStorage[4].pyArray[0])
//                                  (REFilterStorage[1].pyArray[0])   //Only one band

                        );

                    //Code to Bypass Filters...
                    //Stim[0][i]=MicRv[0][i];
                    //Stim[1][i]=MicRv[1][i];

            }



            //-----------------------------------------------------------------------------------------------------------------------------
            //Send Next Audio Buffers...
            //-----------------------------------------------------------------------------------------------------------------------------
            audio_send(&Stim[0][0], &Stim[1][0], buffer_length);









        }


    }
}





